version 9.2
global stub ch1_f06
/*
	GBSG breast cancer data.
	Example to illustrate univariate FP approach.
	Models for nodes, adjusted in multivariable models
	of type linear, cut and FP.
*/
set more off
mvmb_load gbsg_br_ca
mvmb_logopen
qui {
	gen byte pgr_d1 = (pgr<20)
	gen byte nodes_d1 = (nodes>=4)
	gen byte nodes_d2 = (nodes>9)

	* Linear
	local mod 1
	fracpoly stcox gradd1 nodes 1 pgr 1 hormon
	noi di "Deviance for linear model = " -2*e(ll)
	fracpred f_`mod', for(nodes)
	meanzero f_`mod', replace
	* Adjust to nodes 1-3
	sum f_`mod' if nodes_d1==0
	replace f_`mod' = f_`mod'-r(mean)

	* Cutpoint model
	local ++mod
	stcox gradd1 nodes_d1 nodes_d2 pgr_d1 hormon
	noi di "Deviance for cutpoint model = " -2*e(ll)
	gen f_`mod' = _b[nodes_d1]*nodes_d1+_b[nodes_d2]*nodes_d2

	* FP
	local ++mod
	fracpoly stcox age -2 -1 gradd1 nodes 0 pgr 0 hormon
	noi di "Deviance for FP model = " -2*e(ll)
	fracpred f_`mod', for(nodes)
	meanzero f_`mod', replace
	* Adjust to nodes 1-3
	sum f_`mod' if nodes_d1==0
	replace f_`mod' = f_`mod'-r(mean)

	* plot functions
	clp
	local stuff sort clp($clp) ///
	 ytitle("Log relative hazard") xtitle("Number of nodes involved") c(l J l) ///
	 leg(label(1 "Linear") label(2 "Cut(3, 9)") label(3 "FP") ring(0) pos(11) col(1)) ///
	  lcolor(. . gs8)
	line f_1 f_2 f_3 nodes if nodes<=38, `stuff' sav($stub, replace) nodraw
}
log close

gph2emf $stub
gph2eps $stub

set more on
