version 9.2
global stub ch1_t01
/*
	Research body fat data.
	Example to illustrate univariate FP approach.
	Predict percent body fat from BMI and other variables.
	Deviances and R^2 from fits for linear, quadratic, cubic, FP1 and FP2.

	(Note: N = 326. Deleting one observation with missing SBP.)
*/
set more off
mvmb_load res_bodyfat
mvmb_logopen
qui {
	drop if msbp_missing

	* Linear (for comparison only)
	regress pbfm bmi
	noi di _n "Linear:    -2 log L = " %9.3f -2*e(ll) " R^2 = " %6.4f e(r2) " RMSE = " %9.0g e(rmse)

	* Fit quadratic and show results (use orthog polynomials for convenience later)
	orthpoly bmi, degree(3) gen(O*)
	regress pbfm O1 O2
	noi di _n "Quadratic: -2 log L = " %9.3f -2*e(ll) " R^2 = " %6.4f e(r2) " RMSE = " %9.0g e(rmse)

	* Linear and Cubic
	regress pbfm O1
	noi di _n "Linear:    -2 log L = " %9.3f -2*e(ll) " R^2 = " %6.4f e(r2) " RMSE = " %9.0g e(rmse)

	regress pbfm O1 O2 O3
	noi di _n "Cubic:     -2 log L = " %9.3f -2*e(ll) " R^2 = " %6.4f e(r2) " RMSE = " %9.0g e(rmse)
	test O3
	noi di "Test of cubic term: F = " %8.3f r(F) " P = " %6.4f r(p)

	* FP1 and FP2 (MFP selects FP1)
	mfp regress pbfm bmi
	noi di _n "FP1:       -2 log L = " %9.3f -2*e(ll) " R^2 = " %6.4f e(r2) " RMSE = " %9.0g e(rmse)

	fracpoly reg pbfm bmi -2 -1
	noi di _n "FP2:       -2 log L = " %9.3f -2*e(ll) " R^2 = " %6.4f e(r2) " RMSE = " %9.0g e(rmse)
}
log close
set more on
