version 9.2
global stub ch11_f03
/*
	Fetal growth data.
	hemi with running line smoothers and derived age-specific reference interval.
*/
set more off
mvmb_load fetal_growth
mvmb_logopen

local x gawks
local y hemi 
running_ci `y' `x'

residual_plot_cmd s_`x' ll_`x' ul_`x' `x', nozero

twoway `r(cmd2)' ///
 (scatter `y' `x', ytitle("hemi (hemisphere diameter, mm)") ///
 ms(oh) mcolor(gs8) msize(*0.5) xtitle("") ) ///
 `r(cmd3)', name(g1, replace) nodraw

* Absolute residuals
gen mu = s_`x'
gen ar = abs(hemi-s_`x')
local y ar
running_ci `y' `x'

residual_plot_cmd s_`x' ll_`x' ul_`x' `x', nozero

twoway `r(cmd2)' ///
 (scatter `y' `x', ytitle("absolute residuals") ///
 ms(oh) mcolor(gs4) msize(*0.5) xtitle("") ) ///
 `r(cmd3)' , name(g2, replace) nodraw

* 95% reference interval
gen sigma = s_`x'*sqrt(_pi/2)
gen c25 = mu-1.96*sigma
gen c975 = mu+1.96*sigma
twoway (scatter hemi `x', ms(oh) mcolor(gs8) msize(*0.5) xtitle("") ytitle("hemi")) ///
 (line c25 mu c975 `x', sort lcolor(gs4 ..) ), legend(off) name(g3, replace) nodraw

* Z scores
gen z = (hemi-mu)/sigma
local y z
running_ci `y' `x'
residual_plot_cmd s_`x' ll_`x' ul_`x' `x'

twoway `r(cmd2)' ///
 (scatter `y' `x', ytitle("Z-scores") ///
 ms(oh) mcolor(gs4) msize(*0.5) xtitle("") ) ///
 `r(cmd3)' , yline(-1.96 1.96) name(g4, replace) nodraw

graph combine g1 g2 g3 g4, sav($stub, replace) nodraw ///
 b2title("gawks (gestational age, weeks)")

gph2emf $stub
gph2eps $stub

graph drop g1 g2
set more on
