version 9.2
global stub ch2_t07
/*
	Educational body fat data.
	Evaluate Van Houwelingen's l and l*(1) cross-validated likelihood
	for various models. BE(1%, 5%, 15.7%) and full model. With and without
	dominating variable x6. Also parameterwise shrinkage factors (PWSFs).
*/
cap program drop job
program define job
args alpha	// nominal significance level
tempvar res

if `alpha'<1 {
	* Estimate model (note: pe() must be less than pr())
	local alpha2 = `alpha'*.999
	qui stepwise regress pcfat $vars, pr(`alpha') pe(`alpha2')
	local vl: colnames e(b)
	
	* Remove _cons and sort
	local cons _cons
	local vl: list vl - cons
	local vl: list sort vl
}
else local vl $vars

* Cross-val and l*(1) - latter on cross-validated index
qui cval regress pcfat `vl', parameterwise xb

noi di _n "{hline 55}" _n ///
 "alpha = " `alpha' _col(10) " l = " %9.3f -0.5*r(err) _col(25) " l*(1) = " %9.3f -0.5*r(cv) ///
 _n "{hline 55}"

* PWSF
regress pcfat XB*

* Global shrinkage factor
regress pcfat _cval

drop XB*

end

set more off
mvmb_load edu_bodyfat_std
mvmb_logopen

global vars x01-x13

foreach alpha in 1 .157 .05 .01 {
	job `alpha'
}

********************************************************************************
* Same again, but without x6 (dominating variable)

drop x06

foreach alpha in 1 .157 .05 .01 {
	job `alpha'
}


log close
