version 9.2
global stub ch5_f08
/*
	Nerve conduction data.
	Example of FP3.
*/
set more off
mvmb_load nerve
qui {
	fracpoly regress vel age 0 1
	predict fit1
	predict res1, res

	twoway (scatter vel age, ms(oh) mcolor(gs12)) (line fit1 age, sort lwidth(medthick) lcolor(gs2)), ///
	 xtitle("Age, years (log scale)") ytitle("Velocity, m/sec") xsca(log) ///
	 xlab(.5 1 2 5 10 20 50) legend(off) name(g1, replace) nodraw

	local x age
	local y res1
	running_ci `y' `x'
	
	* Truncate residuals to [-5, 5]
	replace res1 = -5 if res1<-5
	replace res1 =  5 if res1>5

	residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-5) yu(5)

	twoway `r(cmd1)' `r(cmd2)' ///
	 (scatter `y' `x', ms(oh) mcolor(gs12) ) ///
	 `r(cmd3)' ///
	 , xtitle("Age, years (log scale)") ytitle("Smoothed residuals (FP2 model)") xsca(log) ///
	  xlab(.5 1 2 5 10 20 50) name(g2, replace) nodraw

	* FP3 model
	fracpoly regress vel age -2 .5 1
	predict fit2
	predict res2, res

	twoway (scatter vel age, ms(oh) mcolor(gs12)) (line fit2 age, sort lwidth(medthick) lcolor(gs2)), ///
	 xtitle("Age, years (log scale)") ytitle("Velocity, m/sec") xsca(log) ///
	 xlab(.5 1 2 5 10 20 50) legend(off) name(g3, replace) nodraw

	local x age
	local y res2
	running_ci `y' `x'

	* Truncate residuals to [-5, 5]
	replace res2 = -5 if res2<-5
	replace res2 =  5 if res2>5

	residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-5) yu(5)

	twoway `r(cmd1)' `r(cmd2)' ///
	 (scatter `y' `x', ms(oh) mcolor(gs12) ) ///
	 `r(cmd3)' ///
	 , xtitle("Age, years (log scale)") ytitle("Smoothed residuals (FP3 model)") xsca(log) ///
	  xlab(.5 1 2 5 10 20 50) name(g4, replace) nodraw
}
graph combine g1 g2 g3 g4, sav($stub, replace) nodraw

gph2emf $stub
gph2eps $stub

graph drop g1 g2 g3 g4
set more on
