version 9.2
global stub ch5_f11
/*
	Kidney cancer data.
	Shows poor fit of FP1 to haemoglobin data.
	Logistic growth-curve model is better.
*/
set more off
mvmb_load kidney_ca
mvmb_logopen

* FP1 and martingale residuals
local x haem
fracgen haem -1, adj(mean)
stcox haem_1, mgale(r)
di "FP1 deviance = " -2*e(ll)
predict f, xb
meanzero f, replace
predict sf, stdp
gen ll = f-1.96*sf
gen ul = f+1.96*sf
gen byte freq = 1

fracpoly stcox haem, com
di "FP2 deviance = " -2*e(ll)

log close

twoway ///
 ( rarea ll ul `x', sort pstyle(ci) ) ///
 ( line f `x', sort lstyle(refline) pstyle(p2) ) ///
 ( spike freq `x', xaxis(2) yaxis(2) yscale(axis(2) r(0 40) off) xscale(axis(2) off) blcolor(black) ) ///
 , ysca(r(-1.5 2)) yla(-1(1)2) ///
 xtitle("") ytitle("Log relative hazard", size(large)) legend(off) name(g1, replace) nodraw

running_ci r `x'
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-1) yu(1.36)

* Truncate martingale residuals to[-1,1]
replace r = -1 if r<-1

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter r `x', ms(oh) mcolor(gs12) ) ///
 `r(cmd3)' ///
 , yla(-1(1)1) ///
 xtitle("") ytitle("Residuals", size(large)) name(g2, replace) nodraw

/*
	Fit logistic growth curve model.
	Note: slightly different from Fig 5.11 in book, since
	it allows for uncertainty in the non-linear parameters.
	This makes the CI for the fitted values wider.
	The fitted values are centered on zero to make them
	comparable with the fitted FP curve.
*/
qui sum haem
gen x = haem-r(mean)
growth cox _t x, logistic dead(_d)
predict f2, xb
meanzero f2, replace
predict sf2, stdp
gen ll2 = f2-1.96*sf2
gen ul2 = f2+1.96*sf2
stcox Ix__1, mgale(r2)

twoway ///
 ( rarea ll2 ul2 `x', sort pstyle(ci) ) ///
 ( line f2 `x', sort lstyle(refline) pstyle(p2) ) ///
 , ysca(r(-1.5 2)) yla(-1(1)2) ///
 xtitle("") ytitle("Log relative hazard", size(large)) legend(off) ///
 name(g3, replace) nodraw

running_ci r2 `x'
residual_plot_cmd s_`x' ll_`x' ul_`x' `x', yl(-1) yu(1.36)

* Truncate r2 to[-1,1]
replace r2 = -1 if r2<-1

twoway `r(cmd1)' `r(cmd2)' ///
 (scatter r2 `x', ms(oh) mcolor(gs12) ) ///
 `r(cmd3)' ///
 , yla(-1(1)1) xtitle("") ytitle("Residuals", size(large)) name(g4, replace) nodraw

graph combine g1 g2 g3 g4, sav($stub, replace) b2title("Haemoglobin (g/dl)") nodraw
gph2emf $stub
gph2eps $stub

graph drop g1 g2 g3 g4
set more off
