version 9.2
global stub ch6_f12
/*
	Prostate data.
	Plots of functions from full mfp model.
*/
set more off
mvmb_load prostate_ca
mvmb_logopen

global contvars cavol weight pgg45 bph cp age
lab var cavol "Cancer volume"
lab var svi "Seminal vessel invasion"
lab var pgg45 "% Gleason score 4 or 5"
lab var bph "Benign prostatic hyperplasia"
lab var age "Age, years"
lab var weight "Prostate weight"
lab var cp "Capsular penetration"

gen byte freq = 1

sum lpsa
scalar mean = r(mean)

* mfp usual
qui fracpoly regress lpsa cavol 0 weight svi
regress

* mfp full
qui mfp regress lpsa $contvars svi, sel(1) alpha(1)
mfp
local j 0
foreach v of var $contvars {
	local ++j
	local pa: word 1 of `e(fp_k`j')'
	local pb: word 2 of `e(fp_k`j')'
	local p`j' (`pa', `pb')
	fracpred f`j', for(`v')
	qui sum f`j'
	qui replace f`j' = f`j'-r(mean)+mean
	fracpred s`j', for(`v') stdp
	gen ll`j' = f`j'-1.96*s`j'
	gen ul`j' = f`j'+1.96*s`j'
}

local j 0
foreach v of var $contvars {
	local ++j
	di "j = `j' p =  `p`j''"
	local l: var lab `v'

	residual_plot_cmd f`j' ll`j' ul`j' `v', nozero

	twoway `r(cmd2)' `r(cmd3)' ///
	 (spike freq `v', xaxis(2) yaxis(2) yscale(axis(2) r(0 40) off) ///
	 xscale(axis(2) off) blcolor(black) ) ///
	 , title("`v' `p`j''") xtitle("`l'") ytitle(" ") name(g`j', replace) nodraw
}

log close

graph combine g1 g2 g3 g4 g5 g6, ///
 sav($stub, replace) ycommon l1title(Fitted values) nodraw

gph2emf $stub
gph2eps $stub

graph drop g1 g2 g3 g4 g5 g6
set more on
