version 9.2
global stub ch6_f13
/*
	Prostate data.
	Plots of 3 functions for cp selected at .25 level,
	with different adjustment models: none, linear, MFP
*/
set more off
mvmb_load prostate_ca

gen lcavol = ln(cavol)

global adjlin cavol weight svi pgg45 bph
global adjmfp lcavol weight svi

sum lpsa
scalar mean = r(mean)

* Unadj: model is FP1 (0)
fracpoly regress lpsa cp 0
predict f1

* adj lin: model is lin
fracpoly regress lpsa cp 1 $adjlin
fracpred f2, for(cp)
qui sum f2
qui replace f2 = f2-r(mean)+mean

* adj MFP: model is 1
fracpoly regress lpsa cp 1 $adjmfp
fracpred f3, for(cp)
qui sum f3
qui replace f3 = f3-r(mean)+mean

gen byte freq = 1

twoway (line f1 f2 f3 cp, xtitle("Capsular penetration (cp), mm", size(large)) ///
 ytitle("Log PSA", size(large)) clp(solid dash longdash_dot) lwidth(medthick ..) sort ///
 legend(label(1 "Unadjusted") label(2 "Adjusted linear BE(0.2)") label(3 "Adjusted MFP(0.2, 0.05)") ///
 order(1 2 3) ring(0) col(1) pos(11))) ///
 (spike freq cp, xaxis(2) yaxis(2) yscale(axis(2) r(0 40) off) ///
  xscale(axis(2) off) blcolor(black) ) ///
 , yla(2(.5)4) ysca(r(1.75 4.25)) sav(${stub}, replace) nodraw

gph2emf $stub
gph2eps $stub
set more on
