version 9.2
global stub ch7_f08
/*
	Kidney cancer data.
	STEPP tail-oriented and sliding window plots.
*/
cap program drop job
program define job
	args vn VN plotn plotstuff log tail param1 param2
/*
	When tail = 0 use sliding window, n1=param1, n2=param2.
	When tail = 1 use tail oriented, g=param1
*/
	tempvar ll ul y1 y2
	if `tail'==0 {
		stepp_window stcox `vn', gen(S) with(trt) n1(`param1') n2(`param2')
		local tit "n1 = `param1', n2 = `param2'"
	}
	else {
		stepp_tail stcox `vn', gen(S) with(trt) g(`param1')
		local tit "g = `param1'"
	}
	gen `ll' = Sb-1.96*Sse
	gen `ul' = Sb+1.96*Sse
	local x Smean

	gen `y1' = 0
	gen `y2' = -0.2924 // log HR for treatment effect, interferon vs. MPA

	residual_plot_cmd Sb `ll' `ul' `x', nozero noparen

	twoway `r(cmd2)' || `r(cmd3)' lwidth(medthick) || ///
	 line `y1' `y2' `x', sort clp(l -) lwidth(thin ..) lcolor(gs6 .) ///
	 , ytitle(" ") , xtitle("`VN'") ytitle(" ") leg(off) title(`"`tit'"') ///
	 `plotstuff' name(g`plotn', replace) nodraw
end

set more off
mvmb_load kidney_ca

local plotstuff xla(5(5)15) xsca(r(4 17)) yla(-1.5(1.5)1.5)
job wcc " " 1 "`plotstuff'" "" 0 25 40
job wcc " " 2 "`plotstuff'" "" 0 40 60
job wcc " " 3 "`plotstuff'" "" 0 50 80
job wcc " " 4 "`plotstuff'" "" 1 8
job wcc " " 5 "`plotstuff'" "" 1 6
job wcc " " 6 "`plotstuff'" "" 1 4

graph combine g1 g2 g3 g4 g5 g6, sav($stub, replace) nodraw ///
 l1title("Beta estimator with 95% conf. band") b2title(White cell count)

gph2emf $stub
gph2eps $stub

graph drop g1 g2 g3 g4 g5 g6
set more on
