version 9.2
global stub ch7_f09
/*
	Kidney cancer data.
	Treatment-effect plot for WCC, selecting adjustment model.
*/
set more off
mvmb_load kidney_ca
/*	
	Compute and plot treatment effect with original data
	Use truncation and origin shift.
*/
gdelta Gwcc = wcc

fracgen t_mt -0.5
fracgen haem -1

mfpi stcox t_mt_1 haem_1 whod1 whod2, showmodel ///
 df(1) select(1) linear(Gwcc) fp1(Gwcc) fp2(Gwcc) ///
 with(trt) gendiff(dorig) genf(f)
 
// Linear interaction has lowest AIC, use it.
gen lorig = dorig1_1-2*dorig1s_1
gen horig = dorig1_1+2*dorig1s_1

// Get adjusted treatment effect
stcox t_mt_1 haem_1 whod1 whod2 trt, nohr nolog

gen y1 = 0
gen y2 = _b[trt]

drop if wcc>20

local x wcc
residual_plot_cmd dorig1_1 lorig horig `x', nozero noparen

twoway `r(cmd2)' || `r(cmd3)' lwidth(medthick) || ///
 line y1 y2 `x', sort clp(l -) lwidth(thin ..) lcolor(gs6 .) ///
 , ytitle("Log hazard ratio (treatment effect)", size(large)) ///
 xlab(5(5)20) xscale(r(2.5 20)) xtitle("White cell count",size(large)) ///
 ylab(-1.5(0.5)1.5) legend(off) sav(${stub}, replace) nodraw

gph2emf $stub
gph2eps $stub

set more on
